@@ -3,6 +3,7 @@ import argparse
 import asyncio
 import logging
 import re
+from copy import deepcopy
 from dataclasses import dataclass
 from typing import Awaitable, Callable, Dict, List, Optional, Union
 
@@ -85,6 +86,7 @@ class HermesApp(HermesClient):
         name: str,
         parser: Optional[argparse.ArgumentParser] = None,
         mqtt_client: Optional[mqtt.Client] = None,
+        **kwargs
     ):
         """Initialize the Rhasspy Hermes app.
 
@@ -97,14 +99,28 @@ class HermesApp(HermesClient):
 
             mqtt_client: An MQTT client. If the argument
                 is not specified, the object creates an MQTT client itself.
+
+            **kwargs: Other arguments. This supports the same arguments as the command-line
+                arguments, such has ``host`` and ``port``. Arguments specified by the user
+                on the command line have precedence over arguments passed as ``**kwargs``.
         """
         if parser is None:
             parser = argparse.ArgumentParser(prog=name)
         # Add default arguments
         hermes_cli.add_hermes_args(parser)
 
-        # Parse command-line arguments
-        self.args = parser.parse_args()
+        # overwrite argument defaults inside parser with argparse.SUPPRESS
+        # so arguments that are not provided get ignored
+        suppress_parser = deepcopy(parser)
+        for action in suppress_parser._actions:
+            action.default = argparse.SUPPRESS
+
+        supplied_args = vars(suppress_parser.parse_args())
+        default_args = vars(parser.parse_args([]))
+
+        # Command-line arguments take precedence over the arguments of the HermesApp.__init__
+        args = {**default_args, **kwargs, **supplied_args}
+        self.args = argparse.Namespace(**args)
 
         # Set up logging
         hermes_cli.setup_logging(self.args)
@@ -115,12 +131,14 @@ class HermesApp(HermesClient):
             mqtt_client = mqtt.Client()
 
         # Initialize HermesClient
+        # pylint: disable=no-member
         super().__init__(name, mqtt_client, site_ids=self.args.site_id)
 
         self._callbacks_hotword: List[Callable[[HotwordDetected], Awaitable[None]]] = []
 
         self._callbacks_intent: Dict[
-            str, List[Callable[[NluIntent], Awaitable[None]]],
+            str,
+            List[Callable[[NluIntent], Awaitable[None]]],
         ] = {}
 
         self._callbacks_intent_not_recognized: List[
@@ -211,8 +229,8 @@ class HermesApp(HermesClient):
             elif DialogueIntentNotRecognized.is_topic(topic):
                 # hermes/dialogueManager/intentNotRecognized
                 try:
-                    dialogue_intent_not_recognized = DialogueIntentNotRecognized.from_json(
-                        payload
+                    dialogue_intent_not_recognized = (
+                        DialogueIntentNotRecognized.from_json(payload)
                     )
                     for function_dinr in self._callbacks_dialogue_intent_not_recognized:
                         await function_dinr(dialogue_intent_not_recognized)
@@ -238,7 +256,7 @@ class HermesApp(HermesClient):
                                         for name, position in named_positions.items():
                                             data.data[name] = parts[position]
 
-                                    function_2(data, payload)
+                                    await function_2(data, payload)
                                     unexpected_topic = False
 
                 if unexpected_topic:
@@ -317,7 +335,6 @@ class HermesApp(HermesClient):
                         self.publish(
                             DialogueEndSession(
                                 session_id=intent.session_id,
-                                site_id=intent.site_id,
                                 text=message.text,
                                 custom_data=message.custom_data,
                             )
@@ -331,7 +348,6 @@ class HermesApp(HermesClient):
                         self.publish(
                             DialogueContinueSession(
                                 session_id=intent.session_id,
-                                site_id=intent.site_id,
                                 text=message.text,
                                 intent_filter=message.intent_filter,
                                 custom_data=message.custom_data,
@@ -390,7 +406,6 @@ class HermesApp(HermesClient):
                     self.publish(
                         DialogueEndSession(
                             session_id=inr.session_id,
-                            site_id=inr.site_id,
                             text=message.text,
                             custom_data=message.custom_data,
                         )
@@ -404,7 +419,6 @@ class HermesApp(HermesClient):
                     self.publish(
                         DialogueContinueSession(
                             session_id=inr.session_id,
-                            site_id=inr.site_id,
                             text=message.text,
                             intent_filter=message.intent_filter,
                             custom_data=message.custom_data,
@@ -458,7 +472,6 @@ class HermesApp(HermesClient):
                     self.publish(
                         DialogueEndSession(
                             session_id=inr.session_id,
-                            site_id=inr.site_id,
                             text=message.text,
                             custom_data=message.custom_data,
                         )
@@ -472,7 +485,6 @@ class HermesApp(HermesClient):
                     self.publish(
                         DialogueContinueSession(
                             session_id=inr.session_id,
-                            site_id=inr.site_id,
                             text=message.text,
                             intent_filter=message.intent_filter,
                             custom_data=message.custom_data,
@@ -593,6 +605,7 @@ class HermesApp(HermesClient):
         self._subscribe_callbacks()
 
         # Try to connect
+        # pylint: disable=no-member
         _LOGGER.debug("Connecting to %s:%s", self.args.host, self.args.port)
         hermes_cli.connect(self.mqtt_client, self.args)
         self.mqtt_client.loop_start()
